
# Slot: part_of

Optional extension allowing hierarchical nesting of CCs

URI: [gocam:cellularAnatomicalEntityAssociation__part_of](https://w3id.org/gocam/cellularAnatomicalEntityAssociation__part_of)


## Domain and Range

None &#8594;  <sub>0..1</sub> [CellTypeAssociation](CellTypeAssociation.md)

## Parents


## Children


## Used by

 * [CellularAnatomicalEntityAssociation](CellularAnatomicalEntityAssociation.md)
